@@ -6,7 +6,7 @@ summary.cfa_model <- function(object, na.print=".", digits=3, ...) {
 
   model_summary     <- summarize_cb_measurement(object)
   model_summary$quality <- list(
-    fit = summarize_fit(object$lavaan_model),
+    fit = summarize_fit(object$lavaan_output),
     reliability = rhoC_AVE(object)
   )
 
